config

package
v1.5.30 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 9, 2026 License: MPL-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidADOConnectionString    = errors.New("failed to parse ADO connection string")
	ErrConnectionStringFileReadError = errors.New("failed to read connection string file")
)
var (
	ErrInvalidMigrationsDirectory = errors.New("invalid migrations directory path")
	ErrInvalidConnectionString    = errors.New("connection string is invalid")
	ErrInvalidSteps               = errors.New("invalid steps: must be positive integer")
	ErrInvalidAppId               = errors.New("app-id is required")
	ErrInvalidConnectionTimeout   = errors.New("connection timeout must be a positive integer")
)

Functions

This section is empty.

Types

type Config

type Config struct {
	// contains filtered or unexported fields
}

Config fields are not exported, making Config immutable Use getters to read a value from the Config struct

func LoadConfig

func LoadConfig(version string) (*Config, error)

func (*Config) AppId

func (cfg *Config) AppId() string

func (*Config) ConnectionString

func (cfg *Config) ConnectionString() string

func (*Config) ConnectionTimeout

func (cfg *Config) ConnectionTimeout() int

func (*Config) Dir

func (cfg *Config) Dir() string

func (*Config) Host

func (cfg *Config) Host() string

func (*Config) SkipFileValidation

func (cfg *Config) SkipFileValidation() bool

func (*Config) Steps

func (cfg *Config) Steps() int

func (*Config) Version

func (cfg *Config) Version() string

Jump to